## Plugin Overview

![alt](https://www.cncf.io/wp-content/uploads/2020/08/prometheusBanner-1.png)
<br/>
<br/>

Welcome to the official NMachine Prometheus plugin. This page will 
let you configure both the plugin and Prometheus itself. 
<br/>
<br/>
If you don't know where to start, try enabling the plugin by 
configuring it to point to your Prometheus instance. From there,
you'll be able to foo bar.
